@@ -18,21 +18,58 @@ import warnings
 from tencentcloud.common.abstract_model import AbstractModel
 
 
+class BoundK8SInfo(AbstractModel):
+    """服务治理引擎绑定的kubernetes信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param BoundClusterId: 绑定的kubernetes集群ID
+        :type BoundClusterId: str
+        :param BoundClusterType: 绑定的kubernetes的集群类型，分tke和eks两种
+注意：此字段可能返回 null，表示取不到有效值。
+        :type BoundClusterType: str
+        """
+        self.BoundClusterId = None
+        self.BoundClusterType = None
+
+
+    def _deserialize(self, params):
+        self.BoundClusterId = params.get("BoundClusterId")
+        self.BoundClusterType = params.get("BoundClusterType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class DescribeSREInstanceAccessAddressRequest(AbstractModel):
     """DescribeSREInstanceAccessAddress请求参数结构体
 
     """
 
     def __init__(self):
-        """
+        r"""
         :param InstanceId: 注册引擎实例Id
         :type InstanceId: str
+        :param VpcId: VPC ID
+        :type VpcId: str
+        :param SubnetId: 子网ID
+        :type SubnetId: str
         """
         self.InstanceId = None
+        self.VpcId = None
+        self.SubnetId = None
 
 
     def _deserialize(self, params):
         self.InstanceId = params.get("InstanceId")
+        self.VpcId = params.get("VpcId")
+        self.SubnetId = params.get("SubnetId")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -48,7 +85,7 @@ class DescribeSREInstanceAccessAddressResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param IntranetAddress: 内网访问地址
         :type IntranetAddress: str
         :param InternetAddress: 公网访问地址
@@ -82,7 +119,7 @@ class DescribeSREInstancesRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Filters: 请求过滤参数
         :type Filters: list of Filter
         :param Limit: 翻页单页查询限制数量[0,1000], 默认值0
@@ -123,7 +160,7 @@ class DescribeSREInstancesResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TotalCount: 总数量
         :type TotalCount: int
         :param Content: 实例记录
@@ -153,7 +190,7 @@ class EnvAddressInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EnvName: 环境名
         :type EnvName: str
         :param EnableConfigInternet: 是否开启config公网
@@ -185,7 +222,7 @@ class EnvInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EnvName: 环境名称
         :type EnvName: str
         :param VpcInfos: 环境对应的网络信息
@@ -242,7 +279,7 @@ class Filter(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Name: 过滤参数名
         :type Name: str
         :param Values: 过滤参数值
@@ -264,13 +301,41 @@ class Filter(AbstractModel):
         
 
 
+class KVPair(AbstractModel):
+    """键值对
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Key: 键
+        :type Key: str
+        :param Value: 值
+        :type Value: str
+        """
+        self.Key = None
+        self.Value = None
+
+
+    def _deserialize(self, params):
+        self.Key = params.get("Key")
+        self.Value = params.get("Value")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class SREInstance(AbstractModel):
     """微服务注册引擎实例
 
     """
 
     def __init__(self):
-        """
+        r"""
         :param InstanceId: 实例ID
         :type InstanceId: str
         :param Name: 名称
@@ -317,6 +382,15 @@ class SREInstance(AbstractModel):
         :param EnableInternet: 注册引擎是否开启公网
 注意：此字段可能返回 null，表示取不到有效值。
         :type EnableInternet: bool
+        :param VpcInfos: 私有网络列表信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :type VpcInfos: list of VpcInfo
+        :param ServiceGovernanceInfos: 服务治理相关信息列表
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ServiceGovernanceInfos: list of ServiceGovernanceInfo
+        :param Tags: 实例的标签信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Tags: list of KVPair
         """
         self.InstanceId = None
         self.Name = None
@@ -336,6 +410,9 @@ class SREInstance(AbstractModel):
         self.EnvInfos = None
         self.EngineRegion = None
         self.EnableInternet = None
+        self.VpcInfos = None
+        self.ServiceGovernanceInfos = None
+        self.Tags = None
 
 
     def _deserialize(self, params):
@@ -362,6 +439,66 @@ class SREInstance(AbstractModel):
                 self.EnvInfos.append(obj)
         self.EngineRegion = params.get("EngineRegion")
         self.EnableInternet = params.get("EnableInternet")
+        if params.get("VpcInfos") is not None:
+            self.VpcInfos = []
+            for item in params.get("VpcInfos"):
+                obj = VpcInfo()
+                obj._deserialize(item)
+                self.VpcInfos.append(obj)
+        if params.get("ServiceGovernanceInfos") is not None:
+            self.ServiceGovernanceInfos = []
+            for item in params.get("ServiceGovernanceInfos"):
+                obj = ServiceGovernanceInfo()
+                obj._deserialize(item)
+                self.ServiceGovernanceInfos.append(obj)
+        if params.get("Tags") is not None:
+            self.Tags = []
+            for item in params.get("Tags"):
+                obj = KVPair()
+                obj._deserialize(item)
+                self.Tags.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class ServiceGovernanceInfo(AbstractModel):
+    """服务治理相关的信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param EngineRegion: 引擎所在的地域
+        :type EngineRegion: str
+        :param BoundK8SInfos: 服务治理引擎绑定的kubernetes集群信息
+        :type BoundK8SInfos: list of BoundK8SInfo
+        :param VpcInfos: 服务治理引擎绑定的网络信息
+        :type VpcInfos: list of VpcInfo
+        """
+        self.EngineRegion = None
+        self.BoundK8SInfos = None
+        self.VpcInfos = None
+
+
+    def _deserialize(self, params):
+        self.EngineRegion = params.get("EngineRegion")
+        if params.get("BoundK8SInfos") is not None:
+            self.BoundK8SInfos = []
+            for item in params.get("BoundK8SInfos"):
+                obj = BoundK8SInfo()
+                obj._deserialize(item)
+                self.BoundK8SInfos.append(obj)
+        if params.get("VpcInfos") is not None:
+            self.VpcInfos = []
+            for item in params.get("VpcInfos"):
+                obj = VpcInfo()
+                obj._deserialize(item)
+                self.VpcInfos.append(obj)
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -377,19 +514,24 @@ class VpcInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param VpcId: Vpc Id
         :type VpcId: str
         :param SubnetId: 子网ID
         :type SubnetId: str
+        :param IntranetAddress: 内网访问地址
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IntranetAddress: str
         """
         self.VpcId = None
         self.SubnetId = None
+        self.IntranetAddress = None
 
 
     def _deserialize(self, params):
         self.VpcId = params.get("VpcId")
         self.SubnetId = params.get("SubnetId")
+        self.IntranetAddress = params.get("IntranetAddress")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
